@@ -88,11 +88,11 @@ L<Locale::Maketext>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>audreyt@audreyt.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004 by Audrey Tang E<lt>audreyt@audreyt.orgE<gt>.
+Copyright 2002, 2003, 2004 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
